#!/bin/bash

set -eux

# Setup reasonable defaults when running outside XCode.
PROJECT_DIR=${PROJECT_DIR:-$PWD}
BUILD_DIR=${BUILD_DIR:-$PWD/build}

SOURCE_CACHE="$HOME/Library/Caches/net.habilis.source"

SHORTVERS='0.8'
VERSION='0.8.4'
DIST_VERS='0_8_4'

if [ -f "$BUILD_DIR"/validator-$VERSION-webletssi/httpd/cgi-bin/check ] ; then exit ; fi

if [ ! -r "$SOURCE_CACHE"/validator-$DIST_VERS.tar.gz ]
then
	mkdir -p "$SOURCE_CACHE"
	pushd "$SOURCE_CACHE"
	curl -fsO http://validator.w3.org/dist/validator-$DIST_VERS.tar.gz
	popd
fi

if [ ! -r "$SOURCE_CACHE"/sgml-lib-$DIST_VERS.tar.gz ]
then
	mkdir -p "$SOURCE_CACHE"
	pushd "$SOURCE_CACHE"
	curl -fsO http://validator.w3.org/dist/sgml-lib-$DIST_VERS.tar.gz
	popd
fi

mkdir -p "$BUILD_DIR"

pushd "$BUILD_DIR"
rm -rf validator-$VERSION

# Unpack Validator
tar xzf "$SOURCE_CACHE"/validator-$DIST_VERS.tar.gz
tar xzf "$SOURCE_CACHE"/sgml-lib-$DIST_VERS.tar.gz

# Add extra files before patching, for easier patch management.
pushd validator-$VERSION
# Add SAC files
cp "$PROJECT_DIR"/validator-SAC-*.conf httpd/conf
cp "$PROJECT_DIR"/check_wrapper.sh httpd/cgi-bin
cp "$PROJECT_DIR"/sendfeedback_wrapper.sh httpd/cgi-bin

# Add weblet files
cp -rp htdocs htdocs-weblet
cp -rp share/templates share/templates-weblet
cp "$PROJECT_DIR"/images/*.gif "$PROJECT_DIR"/images/*.png htdocs-weblet/images

popd

# Create the Stand-Alone-Complex
cp -rp validator-$VERSION validator-$VERSION-sac
pushd validator-$VERSION-sac
patch -p1 < "$PROJECT_DIR"/validator-$SHORTVERS-sac.patch
popd

# Create Weblet
cp -rp validator-$VERSION-sac validator-$VERSION-weblet
pushd validator-$VERSION-weblet
patch -p1 < "$PROJECT_DIR"/validator-$SHORTVERS-weblet.patch
popd

# Build or Patch SSI
cp -rp validator-$VERSION-weblet validator-$VERSION-webletssi

if [ -f "$PROJECT_DIR"/validator-$SHORTVERS-webletssi.patch ]
then
	pushd validator-$VERSION-webletssi
	patch -p1 < "$PROJECT_DIR"/validator-$SHORTVERS-webletssi.patch
	popd
else
	# This branch is used when updating the validator, create patch after completion.
	ln -shf "$BUILD_DIR"/validator-$VERSION-weblet ~/Sites/validator-ssi-build
	URL=`hostname`/~$USER
	~/wget-1.10.2/src/wget -r -nv http://$URL/validator-ssi-build/htdocs-weblet
	~/wget-1.10.2/src/wget -r -nv http://$URL/validator-ssi-build/htdocs-weblet/loading.html
	#rm $URL/validator-ssi-build/htdocs-weblet/check*
	rm -r $URL/validator-ssi-build/htdocs-weblet/images
	cp -rp $URL/validator-ssi-build/htdocs-weblet validator-$VERSION-webletssi
fi

popd
